==> ejc-jltest-api-3.0.0-20240320.031010-88-sources.jar: com/ejianc/business/jltest/margin/vo/RiskPayConfirmationVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 风险金缴纳确认
 * 
 * @author generator
 * 
 */
public class RiskPayConfirmationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long employeeDetailId; // 员工明细主键
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private BigDecimal payableAmount; // 应缴纳金额
    private BigDecimal currentPaymentAmount; // 本期缴纳金额
    private BigDecimal paymentAmountTotal; // 含本期已缴纳金额
    private String proportion; // 含本期已缴纳比例
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额
    private Integer isStaged; // 是否分期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date paymentDate; // 缴纳日期
    private String memo; // 备注
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private Integer billState; // 单据状态（审批必须字段）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date applyForTime; // 申请时间
    private String applyPeopleName; // 申请人姓名
    private String billCode; // 单据编码
    private Integer confirmationState; // 确认状态(-1：待确认 0：确认中    1：已确认 )


    @ReferSerialTransfer(referCode="employee-b")
    public Long getEmployeeDetailId() {
        return employeeDetailId;
    }
    @ReferDeserialTransfer
    public void setEmployeeDetailId(Long employeeDetailId) {
        this.employeeDetailId = employeeDetailId;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getCurrentPaymentAmount() {
        return currentPaymentAmount;
    }

    public void setCurrentPaymentAmount(BigDecimal currentPaymentAmount) {
        this.currentPaymentAmount = currentPaymentAmount;
    }
    public BigDecimal getPaymentAmountTotal() {
        return paymentAmountTotal;
    }

    public void setPaymentAmountTotal(BigDecimal paymentAmountTotal) {
        this.paymentAmountTotal = paymentAmountTotal;
    }
    public String getProportion() {
        return proportion;
    }

    public void setProportion(String proportion) {
        this.proportion = proportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    public Integer getIsStaged() {
        return isStaged;
    }

    public void setIsStaged(Integer isStaged) {
        this.isStaged = isStaged;
    }
    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getApplyForTime() {
        return applyForTime;
    }

    public void setApplyForTime(Date applyForTime) {
        this.applyForTime = applyForTime;
    }
    public String getApplyPeopleName() {
        return applyPeopleName;
    }

    public void setApplyPeopleName(String applyPeopleName) {
        this.applyPeopleName = applyPeopleName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getConfirmationState() {
        return confirmationState;
    }

    public void setConfirmationState(Integer confirmationState) {
        this.confirmationState = confirmationState;
    }
    
}

==> ejc-jltest-api-3.0.0-20240321.010407-93-sources.jar: com/ejianc/business/jltest/margin/vo/RiskPayConfirmationVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 风险金缴纳确认
 * 
 * @author generator
 * 
 */
public class RiskPayConfirmationVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long employeeDetailId; // 员工明细主键
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private BigDecimal payableAmount; // 应缴纳金额
    private BigDecimal currentPaymentAmount; // 本期缴纳金额
    private BigDecimal paymentAmountTotal; // 含本期已缴纳金额
    private String proportion; // 含本期已缴纳比例
    private BigDecimal remainingPaymentAmount; // 剩余缴纳金额
    private Integer isStaged; // 是否分期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date paymentDate; // 缴纳日期
    private String memo; // 备注
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private Integer billState; // 单据状态（审批必须字段）
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date applyForTime; // 申请时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private  Date confirmTime;//确认时间
    private String applyPeopleName; // 申请人姓名
    private String billCode; // 单据编码
    private Integer confirmationState; // 确认状态(-1：待确认 0：确认中    1：已确认 )

    private Integer isok;//是否已确认  0 未确认 1 已确认

    private String submitter;//提交人

    public String getSubmitter() {
        return submitter;
    }

    public void setSubmitter(String submitter) {
        this.submitter = submitter;
    }

    public Integer getIsok() {
        return isok;
    }

    public void setIsok(Integer isok) {
        this.isok = isok;
    }


    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }

    @ReferSerialTransfer(referCode="employee-b")
    public Long getEmployeeDetailId() {
        return employeeDetailId;
    }
    @ReferDeserialTransfer
    public void setEmployeeDetailId(Long employeeDetailId) {
        this.employeeDetailId = employeeDetailId;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public BigDecimal getPayableAmount() {
        return payableAmount;
    }

    public void setPayableAmount(BigDecimal payableAmount) {
        this.payableAmount = payableAmount;
    }
    public BigDecimal getCurrentPaymentAmount() {
        return currentPaymentAmount;
    }

    public void setCurrentPaymentAmount(BigDecimal currentPaymentAmount) {
        this.currentPaymentAmount = currentPaymentAmount;
    }
    public BigDecimal getPaymentAmountTotal() {
        return paymentAmountTotal;
    }

    public void setPaymentAmountTotal(BigDecimal paymentAmountTotal) {
        this.paymentAmountTotal = paymentAmountTotal;
    }
    public String getProportion() {
        return proportion;
    }

    public void setProportion(String proportion) {
        this.proportion = proportion;
    }
    public BigDecimal getRemainingPaymentAmount() {
        return remainingPaymentAmount;
    }

    public void setRemainingPaymentAmount(BigDecimal remainingPaymentAmount) {
        this.remainingPaymentAmount = remainingPaymentAmount;
    }
    public Integer getIsStaged() {
        return isStaged;
    }

    public void setIsStaged(Integer isStaged) {
        this.isStaged = isStaged;
    }
    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Date getApplyForTime() {
        return applyForTime;
    }

    public void setApplyForTime(Date applyForTime) {
        this.applyForTime = applyForTime;
    }
    public String getApplyPeopleName() {
        return applyPeopleName;
    }

    public void setApplyPeopleName(String applyPeopleName) {
        this.applyPeopleName = applyPeopleName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getConfirmationState() {
        return confirmationState;
    }

    public void setConfirmationState(Integer confirmationState) {
        this.confirmationState = confirmationState;
    }
    
}
